# Baboo Dice Game

[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
![Release](https://img.shields.io/github/v/release/vitaliisili/dice_game_python)
![PyPI version](https://img.shields.io/pypi/v/baboo-game)
![Watchers](https://img.shields.io/github/watchers/vitaliisili/dice_game_python?style=social)

#### *Welcome to Baboo Dice Game, an exciting and addictive dice game that will test your luck and strategy!* 

![baboo](https://lh3.googleusercontent.com/pw/AJFCJaWOlNjWnEZ6Lcp7Z8AE3YGCv1CaVTXDX-9VXJxfnNVw_Qljmyfhx-khr0Shs1wI2oESp3tbQ8dmKpcmOHViL-OoKLZE10lQ1qUbnz7cikdgstf7bFq7fds7V1WK7DTMOjJejmubcV0MMieJMfxASOtl=w577-h433-s-no)


## How to run
### ***Method 1***:  *Download or Clone source file:*
- Step 1: Clone repository to your local machine and open the folder
```bash
git clone https://github.com/vitaliisili/dice_game_python
```

- Step 2: Install all requirements run command below
```bash
pip install -r requirements.txt
```

- Step 3: Go to directory `src/baboo_game and` and run file `main.py`
```bash
python3 main.py
```
Or use your favorite IDE to run `main.py`
&nbsp;

&nbsp;
### ***Method 2***:  *Use `pip` and install baboo-game from [PyPi]('https://pypi.org/project/baboo-game/)*
- Step 1: Install baboo-game package from [PyPi]('https://pypi.org/project/baboo-game/)
```bash
pip install baboo-game 
```

- Step 2: Import `main` function from baboo_game
```python
from baboo_game import main
```

- Step 3: Run game
```python
main.start()
```
***If you need `Virtual Environment` in Python look [here](https://www.freecodecamp.org/news/how-to-setup-virtual-environments-in-python/)***

![baboo](https://lh3.googleusercontent. ?authuser=0)